@@ -86,7 +86,7 @@
 #define SOLID_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef SOLID_NO_DEPRECATED
-#  define SOLID_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54b00
+#  define SOLID_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
 #endif
 #ifdef SOLID_NO_DEPRECATED_WARNINGS
 #  define SOLID_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef SOLID_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define SOLID_DEPRECATED_WARNINGS_SINCE SOLID_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define SOLID_DEPRECATED_WARNINGS_SINCE 0x54b00
+#    define SOLID_DEPRECATED_WARNINGS_SINCE 0x54c00
 #  endif
 #endif
 
